/* -*- mode: c++; c-basic-offset: 3; -*- */
#ifndef WPIPE_WOUTPUT_HH
#define WPIPE_WOUTPUT_HH
#include "wtypes.hh"

#include <map>

namespace wpipe {
   class wouttype {
   public:
      wouttype(void);
      wouttype(const str_vect& channels, const std::string& time, 
	       const std::string& dir, const std::string& fmt, 
	       const std::string& type);
      size_t find(const std::string& chan) const;
      const std::string& path(size_t i) const;
      size_t size(void) const;
   private:
      str_vect channelNames;
      str_vect _paths;
   };

   class woutput {
   public:
      woutput(const str_vect& channels, const std::string& time, 
	      const std::string& dir, const std::string& fmt, 
	      const str_vect& types);
      bool enabled(const std::string& name) const;
      const wouttype& operator[](const std::string& name) const;
      wouttype& operator[](const std::string& name);
   private:
      typedef std::map<std::string, wouttype> output_map;
      typedef output_map::value_type omap_value;
      output_map out_map;
   };

   //======================================  Inline accessors
   inline const std::string&
   wouttype::path(size_t i) const {
      return _paths[i];
   }

   inline size_t
   wouttype::size(void) const {
      return _paths.size();
   }

   inline bool
   woutput::enabled(const std::string& name) const {
      return out_map.find(name) != out_map.end();
   }

   inline const wouttype&
   woutput::operator[](const std::string& name) const {
      return out_map.find(name)->second;
   }

   inline wouttype&
   woutput::operator[](const std::string& name) {
      return out_map.find(name)->second;
   }

}  // namespace wpipe

#endif // !defined(WPIPE_WOUTPUT_HH)
